@@ -8,6 +8,8 @@ from io import TextIOWrapper
 from itertools import chain, groupby
 from typing import Iterable, Iterator, Tuple, Union
 
+from sendoff.ctable import CTable
+
 Pathy = Union[str, bytes, os.PathLike]
 
 
@@ -104,16 +106,20 @@ class SDBlock:
             )
             yield record_name, str.join("\n", chunk)
 
-    def write(self, outh: TextIOWrapper) -> None:
+    def write(self, outh: TextIOWrapper, with_newlines: bool = True) -> None:
         """Write an SDBlock to a file-like handle.
 
         Args:
             outh: file-like handle, such as what is returned by open(..., "w")
+            with_newlines: each line is written with a trailing "\\n".
+                The newline character is appended only if it wasn't in the line
 
         """
         print(self.title, file=outh)
         for line in chain(self.mdl, self.metadata):
             outh.write(line)
+            if with_newlines and not line.endswith("\n"):
+                outh.write("\n")
         outh.write("$$$$\n")
 
     def append_record(self, record_name: str, value: str) -> None:
@@ -128,6 +134,56 @@ class SDBlock:
         self.metadata.append(value + "\n")
         self.metadata.append("\n")
 
+    def ctable(self) -> CTable:
+        """Parse out the underlying CTable object from the SDBlock.
+
+        Returns:
+            The CTable object, titled with the SDBlock.title,
+                parsed in from the SDBlock.mdl, but without validation.
+        """
+        ctable = CTable(chain([self.title], self.mdl))
+        return ctable
+
+    def num_atoms(self) -> int:
+        """Get number of atoms as indicated in the MDL block.
+
+        The mdl lines are parsed in to generate a CTable.
+        Based on the format parsed, the number of atoms is parsed
+        from the counts line. Note, this is not the number of atom lines.
+
+        Returns:
+            The number of atoms, parsed in from the counts line.
+        """
+        ctable = self.ctable()
+        return ctable.num_atoms
+
+    def num_bonds(self) -> int:
+        """Get number of bonds as indicated in the MDL block.
+
+        The mdl lines are parsed in to generate a CTable.
+        Based on the format parsed, the number of bonds is parsed
+        from the counts line. Note, this is not the number of bond lines.
+
+        Returns:
+            The number of bonds, parsed in from the counts line.
+        """
+        ctable = self.ctable()
+        return ctable.num_bonds
+
+    def renumber_indices(self) -> None:
+        """Renumber atom and bond indices to be 1-indexed and in order.
+
+        Utilizes the underlying CTable's methods, and overwrites
+        this object's mdl.
+        """
+        ctable = self.ctable()
+        ctable.renumber_indices()
+        # not copy, because we don't care about the ctable we just constructed
+        self.mdl = ctable.lines
+        # pop left, because that is the title line we keep separately
+        self.mdl.popleft()
+        return
+
 
 def parse_sdf(sdfpath: Pathy) -> Iterator[SDBlock]:
     """Parse in SDBlocks from a path. Wrapper around SDBlock.from_lines.
